@@ -1,11 +1,9 @@
 package Pcore::API::Backend::Local::Firebird;
 
-use Pcore qw[-class];
+use Pcore -class;
 
 with qw[Pcore::API::Backend::Local];
 
-no Pcore;
-
 1;
 __END__
 =pod
