@@ -320,7 +320,7 @@ sub _report_file ( $self, $res, $max_path_len ) {
                 },
                 modified => {
                     width => 12,
-                    align => 0,
+                    align => 1,
                 },
             ],
         );
@@ -343,7 +343,7 @@ sub _report_file ( $self, $res, $max_path_len ) {
     if ( $res->severity_range_is('ERROR') ) {
         $self->_total_report->{severity_range}->{error}++;
 
-        $severity = BOLD RED;
+        $severity = BOLD WHITE ON_RED;
     }
     elsif ( $res->severity_range_is('WARNING') ) {
         $self->_total_report->{severity_range}->{warning}++;
@@ -356,7 +356,7 @@ sub _report_file ( $self, $res, $max_path_len ) {
         $severity = BOLD GREEN;
     }
 
-    $severity .= $res->severity_range . q[: ] . $res->severity . q[ - ] . $reversed_severity->{ $res->severity } . RESET;
+    $severity .= q[ ] . $res->severity_range . q[: ] . $res->severity . q[ - ] . $reversed_severity->{ $res->severity } . q[ ] . RESET;
 
     push @row, $severity;
 
@@ -374,7 +374,7 @@ sub _report_file ( $self, $res, $max_path_len ) {
     }
 
     # modified
-    push @row, ( $res->was_changed ? BOLD WHITE ON_RED . ' modified ' . RESET : q[] );
+    push @row, ( $res->was_changed ? BOLD WHITE ON_RED . ' modified ' . RESET : q[ - ] );
 
     print $self->{tbl}->render_row( \@row );
 
