@@ -2,17 +2,6 @@ package Pcore::Util::Sys;
 
 use Pcore;
 
-# in case of error return undef
-sub system {    ## no critic qw[Subroutines::ProhibitBuiltinHomonyms]
-    CORE::system @_;
-
-    die qq[System call exit code: $?] if $? && !defined wantarray;
-
-    return if $?;
-
-    return 1;
-}
-
 sub cpus_num {
     state $cpus_num = do {
         require Sys::CpuAffinity;
